

#define TEXT1 "Thinking                          "
#define TEXT2 "Rows detection                    "
#define TEXT3 "Blocks                            "
#define TEXT4 "WSA and SYM                       "
#define TEXT5 "Dictionary                        "
#define TEXT6 "sorting                           "
#define TEXT7 "calculate segments                "
#define TEXT8 "loading picture                   "
#define TEXT9 "calculating ...                   "
#define TEXT10 "zooming the picture              "
#define TEXT11 "XOCR 4.0"
#define TEXT12 "Unknown character"
#define TEXT13 "Context"
#define TEXT14 "Character"
#define TEXT15 "guess :"
#define TEXT16 "Cancel"
#define TEXT17 "Zoom ?"
#define TEXT18 "Dictionary"
#define TEXT19 "Found in the dictionary"
#define TEXT20 "recog:"
#define TEXT21 "Learn"
#define TEXT22 "Learn"
#define TEXT23 "Accept"
#define TEXT24 "Accept"
#define TEXT25 "Copyright"
#define TEXT26 "send licence-fee: one box of sweets !"
#define TEXT27 "XOCR 4.0"
#define TEXT28 "(c) by Martin Bauer"
#define TEXT29 "This program is FREEWARE"
#define TEXT30 "If there are any questions, e-mail to: "
#define TEXT31 "martin_bauer@s2.maus.de"
#define TEXT32 "or letter to:"
#define TEXT33 "Martin Bauer"
#define TEXT34 "Zeppelinstr. 97"
#define TEXT35 "70193 Stuttgart- Germany"
#define TEXT36 "Tel. 0711/6362008"
#define TEXT37 "File"
#define TEXT38 "Edit"
#define TEXT39 "Start"
#define TEXT40 "Parameter"
#define TEXT41 "Help"
#define TEXT42 "Quit"
#define TEXT43 "Close picture"
#define TEXT44 "open picture"
#define TEXT45 "Information"
#define TEXT46 "Segments"
#define TEXT47 "Picture"
#define TEXT48 "Import from XScanner 1.0"
#define TEXT49 "Export to XEdit 1.0"
#define TEXT50 "insert "
#define TEXT51 "delete"
#define TEXT52 "delete all"
#define TEXT53 "auto-detection"
#define TEXT54 "mirror (Y)"
#define TEXT55 "mirror (X)"
#define TEXT56 "Fit into window"
#define TEXT57 "invert"
#define TEXT58 "zoom"
#define TEXT59 "Parameter"
#define TEXT60 "OCR start"
#define TEXT61 "Segments start"
#define TEXT62 "Segments + OCR start"
#define TEXT63 "Help to <Segments>"
#define TEXT64 "Help to <Rows>"
#define TEXT65 "Help <Picture>"
#define TEXT66 "Hilfe zu <Parameter>"
#define TEXT67 "about XOCR"
#define TEXT68 "file open"
#define TEXT69 "OK"
#define TEXT70 "Cancel"
#define TEXT71 "Folder"
#define TEXT72 "Files"
#define TEXT73 "File :"
#define TEXT74 "Filter" 
#define TEXT75 "Parameter"
#define TEXT76 "Path"
#define TEXT77 "Recognition"
#define TEXT78 "Editor"
#define TEXT79  "Send created text into an editor ?"
#define TEXT80 "Editor :"
#define TEXT81  "Send created text into a file ?"
#define TEXT82 "Flush all buffers ?"
#define TEXT83  "File :"
#define TEXT84  "text.txt"
#define TEXT85 "(Won't be used until Version 5.0 !)"
#define TEXT86  "OCR-Data"
#define TEXT87  "Target/Source"
#define TEXT88  "Trigram  (Version 5.0)"
#define TEXT89  "Neuronal (Version 5.0)"
#define TEXT90  "German   (Version 5.0)"
#define TEXT91  "Englisch (Version 5.0)"
#define TEXT92 "++ ask more" 
#define TEXT93  "guess more ++"
#define TEXT94  "Picture %ld"
#define TEXT95  "Fit into window"
#define TEXT96  "Wrong amount of parameters : \n\n"
#define TEXT97  "%s [-segments] file-name_of_the_dictionary filename_of_the_bmp-picture\n"
#define TEXT99  "Importing dictionary-file %s"
#define TEXT100  "%s file-name_of_the_dictionary\n"

 
