struct Parameter
{
 long Trigram;
 long Semantik;
 long DeutschSemantik;
 long EnglischSemantik;
 long UseEditor;
 long Nachfragen;
 long Faktor; 
 long AlleWoerterbuecher;
 long Woerterbuch;
 char PfadTemp[200];
 char PfadOcr[200];
 char Ziel[200];
 char Editor[200];
 char Dateiname[200];
 char Extensions[500];
};

